==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/StackdriverSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Double;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Map;

public interface StackdriverSpecFluent<A extends StackdriverSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildCreds instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.adapter.stackdriver.StackdriverSpec.Creds getCreds();
    public me.snowdrop.istio.mixer.adapter.stackdriver.StackdriverSpec.Creds buildCreds();
    public A withCreds(me.snowdrop.istio.mixer.adapter.stackdriver.StackdriverSpec.Creds creds);
    public Boolean hasCreds();
    public A withApiKeyCreds(ApiKeyCreds apiKeyCreds);
    public StackdriverSpecFluent.ApiKeyCredsNested<A> withNewApiKeyCreds();
    public StackdriverSpecFluent.ApiKeyCredsNested<A> withNewApiKeyCredsLike(ApiKeyCreds item);
    public A withNewApiKeyCreds(String apiKey);
    public A withAppCredentialsCreds(AppCredentialsCreds appCredentialsCreds);
    public StackdriverSpecFluent.AppCredentialsCredsNested<A> withNewAppCredentialsCreds();
    public StackdriverSpecFluent.AppCredentialsCredsNested<A> withNewAppCredentialsCredsLike(AppCredentialsCreds item);
    public A withNewAppCredentialsCreds(Boolean appCredentials);
    public A withServiceAccountPathCreds(ServiceAccountPathCreds serviceAccountPathCreds);
    public StackdriverSpecFluent.ServiceAccountPathCredsNested<A> withNewServiceAccountPathCreds();
    public StackdriverSpecFluent.ServiceAccountPathCredsNested<A> withNewServiceAccountPathCredsLike(ServiceAccountPathCreds item);
    public A withNewServiceAccountPathCreds(String serviceAccountPath);
    public String getEndpoint();
    public A withEndpoint(String endpoint);
    public Boolean hasEndpoint();
    public A addToLogInfo(String key,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo value);
    public A addToLogInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> map);
    public A removeFromLogInfo(String key);
    public A removeFromLogInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> map);
    public Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> getLogInfo();
    public A withLogInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> logInfo);
    public Boolean hasLogInfo();
    public A addToMetricInfo(String key,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo value);
    public A addToMetricInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> map);
    public A removeFromMetricInfo(String key);
    public A removeFromMetricInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> map);
    public Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> getMetricInfo();
    public A withMetricInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> metricInfo);
    public Boolean hasMetricInfo();
    public String getProjectId();
    public A withProjectId(String projectId);
    public Boolean hasProjectId();
    public Long getPushInterval();
    public A withPushInterval(Long pushInterval);
    public Boolean hasPushInterval();
    public A withNewPushInterval(String arg1);
    public A withNewPushInterval(long arg1);
    
/**
 * This method has been deprecated, please use method buildTrace instead.
 * @return The buildable object.
 */
@Deprecated public Trace getTrace();
    public Trace buildTrace();
    public A withTrace(Trace trace);
    public Boolean hasTrace();
    public A withNewTrace(Double sampleProbability);
    public StackdriverSpecFluent.TraceNested<A> withNewTrace();
    public StackdriverSpecFluent.TraceNested<A> withNewTraceLike(Trace item);
    public StackdriverSpecFluent.TraceNested<A> editTrace();
    public StackdriverSpecFluent.TraceNested<A> editOrNewTrace();
    public StackdriverSpecFluent.TraceNested<A> editOrNewTraceLike(Trace item);

    public interface ApiKeyCredsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ApiKeyCredsFluent<StackdriverSpecFluent.ApiKeyCredsNested<N>>{

        
    public N and();    public N endApiKeyCreds();
}
    public interface AppCredentialsCredsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AppCredentialsCredsFluent<StackdriverSpecFluent.AppCredentialsCredsNested<N>>{

        
    public N and();    public N endAppCredentialsCreds();
}
    public interface ServiceAccountPathCredsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceAccountPathCredsFluent<StackdriverSpecFluent.ServiceAccountPathCredsNested<N>>{

        
    public N and();    public N endServiceAccountPathCreds();
}
    public interface TraceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TraceFluent<StackdriverSpecFluent.TraceNested<N>>{

        
    public N and();    public N endTrace();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/StackdriverSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Double;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Map;

public interface StackdriverSpecFluent<A extends StackdriverSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildCreds instead.
 * @return The buildable object.
 */
@Deprecated public StackdriverSpec.Creds getCreds();
    public StackdriverSpec.Creds buildCreds();
    public A withCreds(StackdriverSpec.Creds creds);
    public Boolean hasCreds();
    public A withApiKeyCreds(ApiKeyCreds apiKeyCreds);
    public StackdriverSpecFluent.ApiKeyCredsNested<A> withNewApiKeyCreds();
    public StackdriverSpecFluent.ApiKeyCredsNested<A> withNewApiKeyCredsLike(ApiKeyCreds item);
    public A withNewApiKeyCreds(String apiKey);
    public A withAppCredentialsCreds(AppCredentialsCreds appCredentialsCreds);
    public StackdriverSpecFluent.AppCredentialsCredsNested<A> withNewAppCredentialsCreds();
    public StackdriverSpecFluent.AppCredentialsCredsNested<A> withNewAppCredentialsCredsLike(AppCredentialsCreds item);
    public A withNewAppCredentialsCreds(Boolean appCredentials);
    public A withServiceAccountPathCreds(ServiceAccountPathCreds serviceAccountPathCreds);
    public StackdriverSpecFluent.ServiceAccountPathCredsNested<A> withNewServiceAccountPathCreds();
    public StackdriverSpecFluent.ServiceAccountPathCredsNested<A> withNewServiceAccountPathCredsLike(ServiceAccountPathCreds item);
    public A withNewServiceAccountPathCreds(String serviceAccountPath);
    public String getEndpoint();
    public A withEndpoint(String endpoint);
    public Boolean hasEndpoint();
    public A withNewEndpoint(String arg1);
    public A withNewEndpoint(StringBuilder arg1);
    public A withNewEndpoint(StringBuffer arg1);
    public A addToLogInfo(String key,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo value);
    public A addToLogInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> map);
    public A removeFromLogInfo(String key);
    public A removeFromLogInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> map);
    public Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> getLogInfo();
    public A withLogInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.LogInfo> logInfo);
    public Boolean hasLogInfo();
    public A addToMetricInfo(String key,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo value);
    public A addToMetricInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> map);
    public A removeFromMetricInfo(String key);
    public A removeFromMetricInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> map);
    public Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> getMetricInfo();
    public A withMetricInfo(Map<String,me.snowdrop.istio.mixer.adapter.stackdriver.MetricInfo> metricInfo);
    public Boolean hasMetricInfo();
    public String getProjectId();
    public A withProjectId(String projectId);
    public Boolean hasProjectId();
    public A withNewProjectId(String arg1);
    public A withNewProjectId(StringBuilder arg1);
    public A withNewProjectId(StringBuffer arg1);
    public Integer getPushInterval();
    public A withPushInterval(Integer pushInterval);
    public Boolean hasPushInterval();
    
/**
 * This method has been deprecated, please use method buildTrace instead.
 * @return The buildable object.
 */
@Deprecated public Trace getTrace();
    public Trace buildTrace();
    public A withTrace(Trace trace);
    public Boolean hasTrace();
    public A withNewTrace(Double sampleProbability);
    public StackdriverSpecFluent.TraceNested<A> withNewTrace();
    public StackdriverSpecFluent.TraceNested<A> withNewTraceLike(Trace item);
    public StackdriverSpecFluent.TraceNested<A> editTrace();
    public StackdriverSpecFluent.TraceNested<A> editOrNewTrace();
    public StackdriverSpecFluent.TraceNested<A> editOrNewTraceLike(Trace item);

    public interface ApiKeyCredsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ApiKeyCredsFluent<StackdriverSpecFluent.ApiKeyCredsNested<N>>{

        
    public N and();    public N endApiKeyCreds();
}
    public interface AppCredentialsCredsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AppCredentialsCredsFluent<StackdriverSpecFluent.AppCredentialsCredsNested<N>>{

        
    public N and();    public N endAppCredentialsCreds();
}
    public interface ServiceAccountPathCredsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceAccountPathCredsFluent<StackdriverSpecFluent.ServiceAccountPathCredsNested<N>>{

        
    public N and();    public N endServiceAccountPathCreds();
}
    public interface TraceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TraceFluent<StackdriverSpecFluent.TraceNested<N>>{

        
    public N and();    public N endTrace();
}


}
